.. image:: https://raw.githubusercontent.com/LUKKIEN/wagtailtrans/master/docs/source/_static/wagtailtrans-logo.png
    :alt: Wagtailtrans logo


.. image:: https://travis-ci.org/LUKKIEN/wagtailtrans.svg?branch=master
    :target: https://travis-ci.org/LUKKIEN/wagtailtrans
    :alt: Build status

.. image:: https://codecov.io/gh/LUKKIEN/wagtailtrans/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/LUKKIEN/wagtailtrans
    :alt: Code coverage

.. image:: https://badge.fury.io/py/wagtailtrans.svg
    :target: https://badge.fury.io/py/wagtailtrans
    :alt: PyPi version

.. image:: https://readthedocs.org/projects/wagtailtrans/badge/?version=latest
    :target: http://wagtailtrans.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status


Wagtail multilanguage module
============================

Support multiple languages for your Wagtail site.

Requirements
------------

 - Python 3.4+
 - Django 1.11+
 - Wagtail 2.0+


Getting started
---------------

Follow our `Getting Started <http://wagtailtrans.readthedocs.io/en/latest/getting_started.html>`_ guide to start integrating Wagtailtrans.


Documentation
-------------

The complete project documentation can be found on `Read the Docs <http://wagtailtrans.readthedocs.io/>`_


Who's using it?
---------------

If you want to see some examples on how Wagtailtrans is running in a production environment you can take a look at the following websites:

* `Hendrix Genetics <https://www.hendrix-genetics.com/>`_
* `Wiskerke Onions <https://www.wiskerke-onions.nl/>`_
